%%
%% This is file `lsfenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% chessfss-src.dtx  (with options: `lsfenc')
%% 
%% chessfss: chess font selection commands
%% Copyright 2005 Ulrike Fischer (skak@nililand.de)
%% -------------------------------------------
%% 
%% This file can be redistributed and/or modified under the terms of
%% the LaTeX Project Public License distributed from CTAN archives in
%% the directory macros/latex/base/lppl.txt; either version 1 of the
%% License, or (at your option) any later version.
%% 
%% For error reports see documentation.
\ProvidesFile{lsfenc.def}
 [2006/06/09 v1.2
         Standard LaTeX file]
\DeclareFontEncoding{LSF}{}{}
\DeclareFontSubstitution{LSF}{skaknew}{m}{n}

%% Symbols from the figurine font (LSF encoding)

\DeclareTextSymbol\cfss@symrook          {LSF}{82}
\DeclareTextSymbol\cfss@symknight        {LSF}{78}
\DeclareTextSymbol\cfss@symbishop        {LSF}{66}
\DeclareTextSymbol\cfss@symqueen         {LSF}{81}
\DeclareTextSymbol\cfss@symking          {LSF}{75}
\DeclareTextSymbol\cfss@sympawn          {LSF}{112}

\DeclareTextSymbolDefault\cfss@symrook          {LSF}
\DeclareTextSymbolDefault\cfss@symknight        {LSF}
\DeclareTextSymbolDefault\cfss@symbishop        {LSF}
\DeclareTextSymbolDefault\cfss@symqueen         {LSF}
\DeclareTextSymbolDefault\cfss@symking          {LSF}
\DeclareTextSymbolDefault\cfss@sympawn          {LSF}

\endinput
%%
%% End of file `lsfenc.def'.
