%%
%% This is file `lsbenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% chessfss-src.dtx  (with options: `lsbenc')
%% 
%% chessfss: chess font selection commands
%% Copyright 2005 Ulrike Fischer (skak@nililand.de)
%% -------------------------------------------
%% 
%% This file can be redistributed and/or modified under the terms of
%% the LaTeX Project Public License distributed from CTAN archives in
%% the directory macros/latex/base/lppl.txt; either version 1 of the
%% License, or (at your option) any later version.
%% 
%% For error reports see documentation.
\ProvidesFile{lsbenc.def}
 [2006/06/09 v1.2
         Standard LaTeX file]
\DeclareFontEncoding{LSB}{}{}
\DeclareFontSubstitution{LSB}{skaknew}{m}{n}

\providecommand\cfss@whitepiececolor{}
\providecommand\cfss@blackpiececolor{}
\providecommand\cfss@whitefieldcolor{}
\providecommand\cfss@blackfieldcolor{}

\@namedef{cfss@showboardencodingLSB}{%
\begin{tabular}{llllll}
\multicolumn{6}{l}{\bfseries Encoding \ttfamily LSB}\\[0.5ex]
 Layer:       & fieldmask
              & field
              & piecemask
              & piece
              & result\\
 WhiteSquare  &
              & (color)
              &
              &\boardfont\cfss@whitepiececolor 0
              &\boardfont\cfss@WhiteEmptySquare\\
 BlackSquare  &
              & (color)
              &
              &\boardfont\cfss@blackpiececolor Z
              &\boardfont\cfss@BlackEmptySquare\\
 WhiteOnWhite &
              & (color)
              &
              &\boardfont\cfss@whitepiececolor K
              &\boardfont\cfss@WhiteKingOnWhite\\
 WhiteOnBlack &
              & (color)
              &
              &\boardfont\cfss@whitepiececolor J
              &\boardfont\cfss@WhiteKingOnBlack\\
 BlackOnWhite &
              & (color)
              &
              &\boardfont\cfss@blackpiececolor k
              &\boardfont\cfss@BlackKingOnWhite\\
 BlackOnBlack &
              & (color)
              &
              &\boardfont\cfss@blackpiececolor j
              &\boardfont\cfss@BlackKingOnBlack\\
\end{tabular}}

%% Symbols from the board font (LSB encoding)

\DeclareTextCommand\cfss@WhiteEmptySquare  {LSB}{{\cfss@whitefieldcolor\cfss@whitepiececolor 0}}
\DeclareTextCommand\cfss@BlackEmptySquare  {LSB}{{\cfss@blackfieldcolor\cfss@blackpiececolor Z}}
\DeclareTextCommand\cfss@WhiteKingOnWhite  {LSB}{{\cfss@whitefieldcolor\cfss@whitepiececolor K}}
\DeclareTextCommand\cfss@BlackKingOnWhite  {LSB}{{\cfss@whitefieldcolor\cfss@blackpiececolor k}}
\DeclareTextCommand\cfss@WhiteKingOnBlack  {LSB}{{\cfss@blackfieldcolor\cfss@whitepiececolor J}}
\DeclareTextCommand\cfss@BlackKingOnBlack  {LSB}{{\cfss@blackfieldcolor\cfss@blackpiececolor j}}
\DeclareTextCommand\cfss@WhiteQueenOnWhite {LSB}{{\cfss@whitefieldcolor\cfss@whitepiececolor Q}}
\DeclareTextCommand\cfss@BlackQueenOnWhite {LSB}{{\cfss@whitefieldcolor\cfss@blackpiececolor q}}
\DeclareTextCommand\cfss@WhiteQueenOnBlack {LSB}{{\cfss@blackfieldcolor\cfss@whitepiececolor L}}
\DeclareTextCommand\cfss@BlackQueenOnBlack {LSB}{{\cfss@blackfieldcolor\cfss@blackpiececolor l}}
\DeclareTextCommand\cfss@WhiteRookOnWhite  {LSB}{{\cfss@whitefieldcolor\cfss@whitepiececolor R}}
\DeclareTextCommand\cfss@BlackRookOnWhite  {LSB}{{\cfss@whitefieldcolor\cfss@blackpiececolor r}}
\DeclareTextCommand\cfss@WhiteRookOnBlack  {LSB}{{\cfss@blackfieldcolor\cfss@whitepiececolor S}}
\DeclareTextCommand\cfss@BlackRookOnBlack  {LSB}{{\cfss@blackfieldcolor\cfss@blackpiececolor s}}
\DeclareTextCommand\cfss@WhiteBishopOnWhite{LSB}{{\cfss@whitefieldcolor\cfss@whitepiececolor B}}
\DeclareTextCommand\cfss@BlackBishopOnWhite{LSB}{{\cfss@whitefieldcolor\cfss@blackpiececolor b}}
\DeclareTextCommand\cfss@WhiteBishopOnBlack{LSB}{{\cfss@blackfieldcolor\cfss@whitepiececolor A}}
\DeclareTextCommand\cfss@BlackBishopOnBlack{LSB}{{\cfss@blackfieldcolor\cfss@blackpiececolor a}}
\DeclareTextCommand\cfss@WhiteKnightOnWhite{LSB}{{\cfss@whitefieldcolor\cfss@whitepiececolor N}}
\DeclareTextCommand\cfss@BlackKnightOnWhite{LSB}{{\cfss@whitefieldcolor\cfss@blackpiececolor n}}
\DeclareTextCommand\cfss@WhiteKnightOnBlack{LSB}{{\cfss@blackfieldcolor\cfss@whitepiececolor M}}
\DeclareTextCommand\cfss@BlackKnightOnBlack{LSB}{{\cfss@blackfieldcolor\cfss@blackpiececolor m}}
\DeclareTextCommand\cfss@WhitePawnOnWhite  {LSB}{{\cfss@whitefieldcolor\cfss@whitepiececolor P}}
\DeclareTextCommand\cfss@BlackPawnOnWhite  {LSB}{{\cfss@whitefieldcolor\cfss@blackpiececolor p}}
\DeclareTextCommand\cfss@WhitePawnOnBlack  {LSB}{{\cfss@blackfieldcolor\cfss@whitepiececolor O}}
\DeclareTextCommand\cfss@BlackPawnOnBlack  {LSB}{{\cfss@blackfieldcolor\cfss@blackpiececolor o}}

%% Symbols from the board font (LSB encoding)

\DeclareTextSymbolDefault\cfss@WhiteEmptySquare  {LSB}
\DeclareTextSymbolDefault\cfss@BlackEmptySquare  {LSB}
\DeclareTextSymbolDefault\cfss@WhiteKingOnWhite  {LSB}
\DeclareTextSymbolDefault\cfss@BlackKingOnWhite  {LSB}
\DeclareTextSymbolDefault\cfss@WhiteKingOnBlack  {LSB}
\DeclareTextSymbolDefault\cfss@BlackKingOnBlack  {LSB}
\DeclareTextSymbolDefault\cfss@WhiteQueenOnWhite {LSB}
\DeclareTextSymbolDefault\cfss@BlackQueenOnWhite {LSB}
\DeclareTextSymbolDefault\cfss@WhiteQueenOnBlack {LSB}
\DeclareTextSymbolDefault\cfss@BlackQueenOnBlack {LSB}
\DeclareTextSymbolDefault\cfss@WhiteRookOnWhite  {LSB}
\DeclareTextSymbolDefault\cfss@BlackRookOnWhite  {LSB}
\DeclareTextSymbolDefault\cfss@WhiteRookOnBlack  {LSB}
\DeclareTextSymbolDefault\cfss@BlackRookOnBlack  {LSB}
\DeclareTextSymbolDefault\cfss@WhiteBishopOnWhite{LSB}
\DeclareTextSymbolDefault\cfss@BlackBishopOnWhite{LSB}
\DeclareTextSymbolDefault\cfss@WhiteBishopOnBlack{LSB}
\DeclareTextSymbolDefault\cfss@BlackBishopOnBlack{LSB}
\DeclareTextSymbolDefault\cfss@WhiteKnightOnWhite{LSB}
\DeclareTextSymbolDefault\cfss@BlackKnightOnWhite{LSB}
\DeclareTextSymbolDefault\cfss@WhiteKnightOnBlack{LSB}
\DeclareTextSymbolDefault\cfss@BlackKnightOnBlack{LSB}
\DeclareTextSymbolDefault\cfss@WhitePawnOnWhite  {LSB}
\DeclareTextSymbolDefault\cfss@BlackPawnOnWhite  {LSB}
\DeclareTextSymbolDefault\cfss@WhitePawnOnBlack  {LSB}
\DeclareTextSymbolDefault\cfss@BlackPawnOnBlack  {LSB}

\endinput
%%
%% End of file `lsbenc.def'.
