%%
%% This is file `lsbc4enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% chessfss-src.dtx  (with options: `lsbc4enc')
%% 
%% chessfss: chess font selection commands
%% Copyright 2005 Ulrike Fischer (skak@nililand.de)
%% -------------------------------------------
%% 
%% This file can be redistributed and/or modified under the terms of
%% the LaTeX Project Public License distributed from CTAN archives in
%% the directory macros/latex/base/lppl.txt; either version 1 of the
%% License, or (at your option) any later version.
%% 
%% For error reports see documentation.
%%
%% LSBC4: An encoding for chessboard chars.
%% that makes it possible to color field and the piece differently.
%% In this encoding the pieces/fields are build with a solid fieldmask
%% and pieceOnWhite chars.
%% If a color package is loaded, the fieldmask will be white or gray.
%% The encoding works with fonts that have solid fieldmasks on position 49-54
%% and the pieceOnWhite chars.
%% Possible free font are skaknew and lucena.

\ProvidesFile{lsbc4enc.def}
 [2006/05/22 v1.0
         Standard LaTeX file]
\DeclareFontEncoding{LSBC4}{}{}
\DeclareFontSubstitution{LSBC4}{skaknew}{m}{n}

\AtBeginDocument{\@ifundefined{color}{%
  \def\color#1{}%
  \PackageWarning{chessfss}
   {You haven't load a color package. I will define the color command to do nothing}{}}{}}

\providecommand\cfss@whitefieldmaskcolor{\color{white}}
\providecommand\cfss@blackfieldmaskcolor{\color{gray}}
\providecommand\cfss@whitepiececolor{}
\providecommand\cfss@blackpiececolor{}

\providecommand\cfss@composefmpcolorchar[4]{%range layer. fm, p
  \makebox[0pt][l]{%
    \csname cfss@#1fieldmaskcolor\endcsname#2}%
  {\csname cfss@#3piececolor\endcsname#4}}%

\@namedef{cfss@showboardencodingLSBC4}{%
\begin{tabular}{llllll}
\multicolumn{6}{l}{\bfseries Encoding \ttfamily LSBC4}\\[0.5ex]
 Layer:       & fieldmask
              & field
              & piecemask
              & piece
              & result\\
 WhiteSquare  &\boardfont\cfss@whitefieldmaskcolor z
              &
              &
              &
              &\boardfont\cfss@WhiteEmptySquare\\
 BlackSquare  &\boardfont\cfss@blackfieldmaskcolor z
              &
              &
              &
              &\boardfont\cfss@BlackEmptySquare\\
 WhiteOnWhite &\boardfont\cfss@whitefieldmaskcolor 1
              &
              &
              &\boardfont\cfss@whitepiececolor K
              &\boardfont\cfss@WhiteKingOnWhite\\
 WhiteOnBlack &\boardfont\cfss@blackfieldmaskcolor 1
              &
              &
              &\boardfont\cfss@whitepiececolor K
              &\boardfont\cfss@WhiteKingOnBlack\\
 BlackOnWhite &\boardfont\cfss@whitefieldmaskcolor 1
              &
              &
              &\boardfont\cfss@blackpiececolor k
              &\boardfont\cfss@BlackKingOnWhite\\
 BlackOnBlack &\boardfont\cfss@blackfieldmaskcolor 1
              &
              &
              &\boardfont\cfss@blackpiececolor k
              &\boardfont\cfss@BlackKingOnBlack\\
\end{tabular}}

\DeclareTextCommand\cfss@WhiteEmptySquare {LSBC4}{{\cfss@whitefieldmaskcolor z}}
\DeclareTextCommand\cfss@BlackEmptySquare {LSBC4}%
  {{\cfss@blackfieldmaskcolor z}}
\DeclareTextCommand\cfss@WhiteKingOnWhite {LSBC4}%
    {\cfss@composefmpcolorchar
      {white}{1}
      {white}{K}}
\DeclareTextCommand\cfss@BlackKingOnWhite  {LSBC4}
   {\cfss@composefmpcolorchar
      {white}{1}
      {black}{k}}
\DeclareTextCommand\cfss@WhiteKingOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{1}
      {white}{K}}
\DeclareTextCommand\cfss@BlackKingOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{1}
      {black}{k}}

\DeclareTextCommand\cfss@WhiteQueenOnWhite {LSBC4}%
    {\cfss@composefmpcolorchar
      {white}{5}
      {white}{Q}}
\DeclareTextCommand\cfss@BlackQueenOnWhite  {LSBC4}
   {\cfss@composefmpcolorchar
      {white}{5}
      {black}{q}}
\DeclareTextCommand\cfss@WhiteQueenOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{5}
      {white}{Q}}
\DeclareTextCommand\cfss@BlackQueenOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{5}
      {black}{q}}

\DeclareTextCommand\cfss@WhiteRookOnWhite {LSBC4}%
    {\cfss@composefmpcolorchar
      {white}{3}
      {white}{R}}
\DeclareTextCommand\cfss@BlackRookOnWhite  {LSBC4}
   {\cfss@composefmpcolorchar
      {white}{3}
      {black}{r}}
\DeclareTextCommand\cfss@WhiteRookOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{3}
      {white}{R}}
\DeclareTextCommand\cfss@BlackRookOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{3}
      {black}{r}}

\DeclareTextCommand\cfss@WhiteBishopOnWhite {LSBC4}%
    {\cfss@composefmpcolorchar
      {white}{4}
      {white}{B}}
\DeclareTextCommand\cfss@BlackBishopOnWhite  {LSBC4}
   {\cfss@composefmpcolorchar
      {white}{4}
      {black}{b}}
\DeclareTextCommand\cfss@WhiteBishopOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{4}
      {white}{B}}
\DeclareTextCommand\cfss@BlackBishopOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{4}
      {black}{b}}

\DeclareTextCommand\cfss@WhiteKnightOnWhite {LSBC4}%
    {\cfss@composefmpcolorchar
      {white}{2}
      {white}{N}}
\DeclareTextCommand\cfss@BlackKnightOnWhite  {LSBC4}
   {\cfss@composefmpcolorchar
      {white}{2}
      {black}{n}}
\DeclareTextCommand\cfss@WhiteKnightOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{2}
      {white}{N}}
\DeclareTextCommand\cfss@BlackKnightOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{2}
      {black}{n}}

\DeclareTextCommand\cfss@WhitePawnOnWhite {LSBC4}%
    {\cfss@composefmpcolorchar
      {white}{6}
      {white}{P}}
\DeclareTextCommand\cfss@BlackPawnOnWhite  {LSBC4}
   {\cfss@composefmpcolorchar
      {white}{6}
      {black}{p}}
\DeclareTextCommand\cfss@WhitePawnOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{6}
      {white}{P}}
\DeclareTextCommand\cfss@BlackPawnOnBlack  {LSBC4}
   {\cfss@composefmpcolorchar
      {black}{6}
      {black}{p}}

\endinput
%%
%% End of file `lsbc4enc.def'.
