%%
%% This is file `lsb2enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% chessfss-src.dtx  (with options: `lsb2enc')
%% 
%% chessfss: chess font selection commands
%% Copyright 2005 Ulrike Fischer (skak@nililand.de)
%% -------------------------------------------
%% 
%% This file can be redistributed and/or modified under the terms of
%% the LaTeX Project Public License distributed from CTAN archives in
%% the directory macros/latex/base/lppl.txt; either version 1 of the
%% License, or (at your option) any later version.
%% 
%% For error reports see documentation.
%%
%% LSB2: An encoding for chessboard chars
%% that makes it possible to color field and the piece differently.
%% In this encoding the pieces/fields are build only with the pieceOnWhite characters.
%% Black fields must get their color through commands like \colorbox.
%% The color of the background will shine through the inner of the pieces
%% The solid fieldmask layer, the field layer and the piecemask layer are not used.
%% The encoding works with fonts that have the pieceOnWhite chars. (This should be all fonts)
%% It will not give a professional looking result because of the colored inside of the chars!

\ProvidesFile{lsb2enc.def}
 [2006/06/09 v1.1
         Standard LaTeX file]

\DeclareFontEncoding{LSB2}{}{}
\DeclareFontSubstitution{LSB2}{skaknew}{m}{n}

\providecommand\cfss@whitepiececolor{}
\providecommand\cfss@blackpiececolor{}

\providecommand\cfss@composepcolorchar[2]{%range layer: p
  {\csname cfss@#1piececolor\endcsname#2}}%

\@namedef{cfss@showboardencodingLSB2}{%
\begin{tabular}{llllll}
\multicolumn{6}{l}{\bfseries Encoding \ttfamily LSB2}\\
\multicolumn{6}{l}{fields have no color!}\\[0.5ex]
 Layer:       & fieldmask
              & field
              & piecemask
              & piece
              & result\\
 WhiteSquare  &
              &
              &
              &
              &\boardfont\cfss@WhiteEmptySquare\\
 BlackSquare  &
              &
              &
              &
              &\boardfont\cfss@BlackEmptySquare\\
 WhiteOnWhite &
              &
              &
              &\boardfont\cfss@whitepiececolor K
              &\boardfont\cfss@WhiteKingOnWhite\\
 WhiteOnBlack &
              &
              &
              &\boardfont\cfss@whitepiececolor K
              &\boardfont\cfss@WhiteKingOnBlack\\
 BlackOnWhite &
              &
              &
              &\boardfont\cfss@blackpiececolor k
              &\boardfont\cfss@BlackKingOnWhite\\
 BlackOnBlack &
              &
              &
              &\boardfont\cfss@blackpiececolor k
              &\boardfont\cfss@BlackKingOnBlack\\
\end{tabular}}

\DeclareTextCommand\cfss@WhiteEmptySquare  {LSB2}{\phantom{Z}}
\DeclareTextCommand\cfss@BlackEmptySquare  {LSB2}{\phantom{Z}}
\DeclareTextCommand\cfss@WhiteKingOnWhite  {LSB2}{\cfss@composepcolorchar{white}{K}}
\DeclareTextCommand\cfss@BlackKingOnWhite  {LSB2}{\cfss@composepcolorchar{black}{k}}
\DeclareTextCommand\cfss@WhiteKingOnBlack  {LSB2}{\cfss@composepcolorchar{white}{K}}
\DeclareTextCommand\cfss@BlackKingOnBlack  {LSB2}{\cfss@composepcolorchar{black}{k}}
\DeclareTextCommand\cfss@WhiteQueenOnWhite {LSB2}{\cfss@composepcolorchar{white}{Q}}
\DeclareTextCommand\cfss@BlackQueenOnWhite {LSB2}{\cfss@composepcolorchar{black}{q}}
\DeclareTextCommand\cfss@WhiteQueenOnBlack {LSB2}{\cfss@composepcolorchar{white}{Q}}
\DeclareTextCommand\cfss@BlackQueenOnBlack {LSB2}{\cfss@composepcolorchar{black}{q}}
\DeclareTextCommand\cfss@WhiteRookOnWhite  {LSB2}{\cfss@composepcolorchar{white}{R}}
\DeclareTextCommand\cfss@BlackRookOnWhite  {LSB2}{\cfss@composepcolorchar{black}{r}}
\DeclareTextCommand\cfss@WhiteRookOnBlack  {LSB2}{\cfss@composepcolorchar{white}{R}}
\DeclareTextCommand\cfss@BlackRookOnBlack  {LSB2}{\cfss@composepcolorchar{black}{r}}
\DeclareTextCommand\cfss@WhiteBishopOnWhite{LSB2}{\cfss@composepcolorchar{white}{B}}
\DeclareTextCommand\cfss@BlackBishopOnWhite{LSB2}{\cfss@composepcolorchar{black}{b}}
\DeclareTextCommand\cfss@WhiteBishopOnBlack{LSB2}{\cfss@composepcolorchar{white}{B}}
\DeclareTextCommand\cfss@BlackBishopOnBlack{LSB2}{\cfss@composepcolorchar{black}{b}}
\DeclareTextCommand\cfss@WhiteKnightOnWhite{LSB2}{\cfss@composepcolorchar{white}{N}}
\DeclareTextCommand\cfss@BlackKnightOnWhite{LSB2}{\cfss@composepcolorchar{black}{n}}
\DeclareTextCommand\cfss@WhiteKnightOnBlack{LSB2}{\cfss@composepcolorchar{white}{N}}
\DeclareTextCommand\cfss@BlackKnightOnBlack{LSB2}{\cfss@composepcolorchar{black}{n}}
\DeclareTextCommand\cfss@WhitePawnOnWhite  {LSB2}{\cfss@composepcolorchar{white}{P}}
\DeclareTextCommand\cfss@BlackPawnOnWhite  {LSB2}{\cfss@composepcolorchar{black}{p}}
\DeclareTextCommand\cfss@WhitePawnOnBlack  {LSB2}{\cfss@composepcolorchar{white}{P}}
\DeclareTextCommand\cfss@BlackPawnOnBlack  {LSB2}{\cfss@composepcolorchar{black}{p}}

\endinput
%%
%% End of file `lsb2enc.def'.
