%%
%% This is file `lsienc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% chessfss-src.dtx  (with options: `lsienc')
%% 
%% chessfss: chess font selection commands
%% Copyright 2005 Ulrike Fischer (skak@nililand.de)
%% -------------------------------------------
%% 
%% This file can be redistributed and/or modified under the terms of
%% the LaTeX Project Public License distributed from CTAN archives in
%% the directory macros/latex/base/lppl.txt; either version 1 of the
%% License, or (at your option) any later version.
%% 
%% For error reports see documentation.
\ProvidesFile{lsienc.def}
 [2006/06/09 v1.2
         Standard LaTeX file]
\DeclareFontEncoding{LSI}{}{}
\DeclareFontSubstitution{LSI}{skaknew}{m}{n}

%% Symbols from the figurine font (LSI encoding)

\DeclareTextSymbol\cfss@castlinghyphen{LSI}{45}
\DeclareTextSymbol\cfss@checksymbol   {LSI}{43}
\DeclareTextSymbol\cfss@bishoppair    {LSI}{97}
\DeclareTextSymbol\cfss@betteris      {LSI}{98}
\DeclareTextSymbol\cfss@wupperhand    {LSI}{99}
\DeclareTextSymbol\cfss@doublepawns   {LSI}{100}
\DeclareTextSymbol\cfss@bupperhand    {LSI}{101}
\DeclareTextSymbol\cfss@wbetter       {LSI}{102}
\DeclareTextSymbol\cfss@bbetter       {LSI}{103}
\DeclareTextSymbol\cfss@wdecisive     {LSI}{104}
\DeclareTextSymbol\cfss@bdecisive     {LSI}{105}
\DeclareTextSymbol\cfss@equal         {LSI}{106}
\DeclareTextSymbol\cfss@unclear       {LSI}{107}
\DeclareTextSymbol\cfss@chesssee      {LSI}{108}
\DeclareTextSymbol\cfss@mate          {LSI}{109}
\DeclareTextSymbol\cfss@compensation  {LSI}{110}
\DeclareTextSymbol\cfss@opposbishops  {LSI}{111}
\DeclareTextSymbol\cfss@seppawns      {LSI}{113}
\DeclareTextSymbol\cfss@passedpawn    {LSI}{114}
\DeclareTextSymbol\cfss@samebishops   {LSI}{115}
\DeclareTextSymbol\cfss@devadvantage  {LSI}{116}
\DeclareTextSymbol\cfss@unitedpawns   {LSI}{117}
\DeclareTextSymbol\cfss@with          {LSI}{118}
\DeclareTextSymbol\cfss@without       {LSI}{119}
\DeclareTextSymbol\cfss@markera       {LSI}{120}
\DeclareTextSymbol\cfss@markerb       {LSI}{121}
\DeclareTextSymbol\cfss@withattack    {LSI}{65}
\DeclareTextSymbol\cfss@withinit      {LSI}{67}
\DeclareTextSymbol\cfss@zugzwang      {LSI}{68}
\DeclareTextSymbol\cfss@withidea      {LSI}{69}
\DeclareTextSymbol\cfss@onlymove      {LSI}{70}
\DeclareTextSymbol\cfss@diagonal      {LSI}{71}
\DeclareTextSymbol\cfss@file          {LSI}{72}
\DeclareTextSymbol\cfss@centre        {LSI}{73}
\DeclareTextSymbol\cfss@weakpt        {LSI}{74}
\DeclareTextSymbol\cfss@ending        {LSI}{76}
\DeclareTextSymbol\cfss@qside         {LSI}{77}
\DeclareTextSymbol\cfss@kside         {LSI}{79}
\DeclareTextSymbol\cfss@etc           {LSI}{80}
\DeclareTextSymbol\cfss@morepawns     {LSI}{83}
\DeclareTextSymbol\cfss@timelimit     {LSI}{84}
\DeclareTextSymbol\cfss@moreroom      {LSI}{85}
\DeclareTextSymbol\cfss@counterplay   {LSI}{86}
\DeclareTextSymbol\cfss@capturesymbol {LSI}{88}

\DeclareTextSymbolDefault\cfss@castlinghyphen{LSI}
\DeclareTextSymbolDefault\cfss@checksymbol   {LSI}
\DeclareTextSymbolDefault\cfss@bishoppair    {LSI}
\DeclareTextSymbolDefault\cfss@betteris      {LSI}
\DeclareTextSymbolDefault\cfss@wupperhand    {LSI}
\DeclareTextSymbolDefault\cfss@doublepawns   {LSI}
\DeclareTextSymbolDefault\cfss@bupperhand    {LSI}
\DeclareTextSymbolDefault\cfss@wbetter       {LSI}
\DeclareTextSymbolDefault\cfss@bbetter       {LSI}
\DeclareTextSymbolDefault\cfss@wdecisive     {LSI}
\DeclareTextSymbolDefault\cfss@bdecisive     {LSI}
\DeclareTextSymbolDefault\cfss@equal         {LSI}
\DeclareTextSymbolDefault\cfss@unclear       {LSI}
\DeclareTextSymbolDefault\cfss@see           {LSI}
\DeclareTextSymbolDefault\cfss@mate          {LSI}
\DeclareTextSymbolDefault\cfss@compensation  {LSI}
\DeclareTextSymbolDefault\cfss@opposbishops  {LSI}
\DeclareTextSymbolDefault\cfss@seppawns      {LSI}
\DeclareTextSymbolDefault\cfss@passedpawn    {LSI}
\DeclareTextSymbolDefault\cfss@samebishops   {LSI}
\DeclareTextSymbolDefault\cfss@devadvantage  {LSI}
\DeclareTextSymbolDefault\cfss@unitedpawns   {LSI}
\DeclareTextSymbolDefault\cfss@with          {LSI}
\DeclareTextSymbolDefault\cfss@without       {LSI}
\DeclareTextSymbolDefault\cfss@markera       {LSI}
\DeclareTextSymbolDefault\cfss@markerb       {LSI}
\DeclareTextSymbolDefault\cfss@withattack    {LSI}
\DeclareTextSymbolDefault\cfss@withinit      {LSI}
\DeclareTextSymbolDefault\cfss@zugzwang      {LSI}
\DeclareTextSymbolDefault\cfss@withidea      {LSI}
\DeclareTextSymbolDefault\cfss@onlymove      {LSI}
\DeclareTextSymbolDefault\cfss@diagonal      {LSI}
\DeclareTextSymbolDefault\cfss@file          {LSI}
\DeclareTextSymbolDefault\cfss@centre        {LSI}
\DeclareTextSymbolDefault\cfss@weakpt        {LSI}
\DeclareTextSymbolDefault\cfss@ending        {LSI}
\DeclareTextSymbolDefault\cfss@qside         {LSI}
\DeclareTextSymbolDefault\cfss@kside         {LSI}
\DeclareTextSymbolDefault\cfss@etc           {LSI}
\DeclareTextSymbolDefault\cfss@morepawns     {LSI}
\DeclareTextSymbolDefault\cfss@timelimit     {LSI}
\DeclareTextSymbolDefault\cfss@moreroom      {LSI}
\DeclareTextSymbolDefault\cfss@counterplay   {LSI}
\DeclareTextSymbolDefault\cfss@capturesymbol {LSI}

\endinput
%%
%% End of file `lsienc.def'.
